@@ -115,6 +115,23 @@ class dxr_file:
             self.samba.createDirectory(self.service_name, path)
             return True
         except OperationFailure:
+            # 判断连接
+            return False
+        
+    def deleteDir(self, path):
+        """
+        删除文件夹
+        :param samba:
+        :param path:
+        :return:
+        """
+        try:
+            # path 是用多级目录的形式，如：/test/1/2/3
+            print('删除文件夹', path)
+            self.samba.deleteDirectory(self.service_name, path)
+            return True
+        except Exception as e:
+            print(e)
             return False
 
     def upload(self, smb_dir, local_dir, f_name):
@@ -149,11 +166,12 @@ class dxr_file:
             return ''
         
 if __name__ == '__main__':
-    smb = dxr_file('10.10.8.156', 445, 'smbuser', '123456', return_port=880)
+    smb = dxr_file('10.10.10.53', 445, 'smbuser', '123456', return_port=880)
     # 上传本文件夹下的lu.wav文件
-    for i in range(10):
-        print(smb.upload('dxr/test', 'test', 'requirements.txt'))
-        # 下载test/test文件夹下的lu.wav文件
-        current_dir = os.path.dirname(__file__)
-        time.sleep(1)
-        print(smb.download(['requirements.txt'], 'dxr/test', current_dir.join('t1')))
\ No newline at end of file
+    # for i in range(10):
+    #     print(smb.upload('dxr/test', 'test', 'requirements.txt'))
+    #     # 下载test/test文件夹下的lu.wav文件
+    #     current_dir = os.path.dirname(__file__)
+    #     time.sleep(1)
+    #     print(smb.download(['requirements.txt'], 'dxr/test', current_dir.join('t1')))
+    print(smb.deleteDir('dxr'))
\ No newline at end of file
