@@ -1,7 +1,10 @@
 import asyncio
 import os
+import stat
 import types
 import re
+from Dxr_mqtt.dxr_log import *
+
 
 # 判断系统类型，如果是windows则引入wexpect，如果是linux则引入pexpect
 if os.name == 'nt':
@@ -56,7 +59,8 @@ class MyThread(threading.Thread):
                 # 获取临时文件名
                 file_name_list = os.listdir(file_path)
                 # print(file_name_list)
-                file_name = [i for i in file_name_list if i.startswith('.' + file_name + '.')][0]
+                file_name = [i for i in file_name_list if i.startswith(file_name)]
+                file_name = file_name[0] if file_name else None
                 # 如果为空，则continue
                 if not file_name:
                     continue
@@ -73,7 +77,7 @@ class MyThread(threading.Thread):
                 if file_size == self.file_size:
                     break
             except Exception as e:
-                continue
+                print(e)
 
     def stop(self):
         self.process_ = 100
@@ -123,10 +127,9 @@ def ssh_is_file_exist(remote_path, ip, user_name, password, port=22):
             ssh.sendline('yes')
             ssh.expect(password_key)
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
         elif i == 1:
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
+        ssh.expect(pexpect.EOF)
         file_list_str = ssh.before
         if isinstance(file_list_str, bytes):
             file_list_str = file_list_str.decode('utf-8')
@@ -149,10 +152,9 @@ def ssh_get_file_list(remote_path, ip, user_name, password, port=22):
             ssh.sendline('yes')
             ssh.expect(password_key)
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
         elif i == 1:
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
+        ssh.expect(pexpect.EOF)
         file_list_str = ssh.before
         # 如果file_list_str是bytes类型，则转换成str类型
         if isinstance(file_list_str, bytes):
@@ -160,7 +162,12 @@ def ssh_get_file_list(remote_path, ip, user_name, password, port=22):
         if 'No such file or directory' in file_list_str:
             return None
         file_list = file_list_str.split('\r\n')
-        file_list = file_list[1:-1]
+        for i in file_list:
+            if i.count('drwxr') > 1:
+                new_i =[f'drwxr{o}' for o in i.split('drwxr')]
+                file_list = new_i + file_list
+        # print(f'file_list11: {file_list}')
+        file_list = file_list[1:-1] if os.name != 'nt' else file_list[1:]
         # 对列表进行处理成一个字典的列表，键分别为权限，文件个数，所有者，所属组，大小，更新时间，文件名
         file_list_dict = []
         for f in file_list:
@@ -188,16 +195,17 @@ def ssh_get_file_list(remote_path, ip, user_name, password, port=22):
 
 @download_file
 def ssh_download_file(remote_path, local_path, ip, user_name, password, port=22, callback=None):
-     # cmd = 'scp %s@%s:%s %s' % (user_name, ip, remote_path, local_path)
+    # 使用scp下载文件，同时使用-c参数，使用压缩传输，提高传输速度
     cmd = 'scp -P %s %s@%s:%s %s' % (port, user_name, ip, remote_path, local_path)
+    # cmd = 'scp -c -P %s %s@%s:%s %s' % (port, user_name, ip, remote_path, local_path)
     print(cmd)
     ssh = pexpect.spawn(cmd)
     # 不设置超时时间，因为下载文件的时间不确定
     try:
         get_file_size_index = 0
+        file_size = ssh_get_file_size(remote_path, ip, user_name, password, port)
         # 获取文件大小
         while True:
-            file_size = ssh_get_file_size(remote_path, ip, user_name, password, port)
             if file_size:
                 break
             get_file_size_index += 1
@@ -212,6 +220,13 @@ def ssh_download_file(remote_path, local_path, ip, user_name, password, port=22,
         local_file_path = local_path + file_name
         # 如果本地文件已经存在，则删除
         if os.path.exists(local_file_path):
+            # 删除localfile的只读属性
+            # 如果是windows系统
+            if os.name == 'nt':
+                os.system(f"attrib -r {local_file_path}")
+            else:
+                # 给文件添加可写权限
+                os.chmod(local_file_path, stat.S_IWRITE)
             os.remove(local_file_path)
             time.sleep(1)
         i = ssh.expect([is_input_yes, password_key, pexpect.EOF, pexpect.TIMEOUT])
@@ -229,7 +244,6 @@ def ssh_download_file(remote_path, local_path, ip, user_name, password, port=22,
         before_str = ssh.before
         if isinstance(before_str, bytes):
             before_str = before_str.decode('utf-8')
-        # print(f'ssh before: {before_str}')
         if 'rsync error' in before_str:
             print('rsync error')
             ssh.close()
@@ -306,18 +320,18 @@ def ssh_upload_file(local_path, remote_path, ip, user_name, password, port=22):
             ssh.sendline('yes')
             ssh.expect(password_key)
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
-            before_str = ssh.before
-            if isinstance(before_str, bytes):
-                before_str = before_str.decode('utf-8')
-            print(f'ssh before: {before_str}')
         elif i == 1:
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
-            before_str = ssh.before
-            if isinstance(before_str, bytes):
-                before_str = before_str.decode('utf-8')
-            print(f'ssh before: {before_str}')
+        ssh.expect(pexpect.EOF)
+        before_str = ssh.before
+        if isinstance(before_str, bytes):
+            before_str = before_str.decode('utf-8')
+        print(f'ssh before: {before_str}')
+        # 如果100%都没有出现，则说明上传失败
+        if '100%' not in before_str:
+            ssh.close()
+            return False
+        ssh.close()
         return True
     except pexpect.EOF:
         print('EOF')
@@ -338,10 +352,10 @@ def ssh_rename_file(old_path, new_path, ip, user_name, password, port=22):
             ssh.sendline('yes')
             ssh.expect(password_key)
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
         elif i == 1:
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
+        ssh_before = ssh.expect(pexpect.EOF)
+        print(f'ssh before: {ssh_before}')
         return True
     except pexpect.EOF:
         print('EOF')
@@ -359,6 +373,7 @@ def ssh_delete_file(path, ip, user_name, password, port=22):
         return False
     # cmd = 'ssh %s@%s rm -rf %s' % (user_name, ip, path)
     cmd = 'ssh -p %s %s@%s rm -rf %s' % (port, user_name, ip, path)
+    # print(f'delete file cmd: {cmd}')
     ssh = pexpect.spawn(cmd)
     try:
         i = ssh.expect([is_input_yes, password_key, pexpect.EOF, pexpect.TIMEOUT], timeout=60)
@@ -366,10 +381,34 @@ def ssh_delete_file(path, ip, user_name, password, port=22):
             ssh.sendline('yes')
             ssh.expect(password_key)
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
         elif i == 1:
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
+        ssh_before = ssh.expect(pexpect.EOF)
+        print(f'ssh before: {ssh_before}')
+        return True
+    except pexpect.EOF:
+        print('EOF')
+        ssh.close()
+        return False
+    except pexpect.TIMEOUT:
+        print('TIMEOUT')
+        ssh.close()
+        return False
+
+def ssh_delete_dir(path, ip, user_name, password, port=22):
+    # cmd = 'ssh %s@%s rm -rf %s' % (user_name, ip, path)
+    cmd = 'ssh -p %s %s@%s rm -rf %s' % (port, user_name, ip, path)
+    # print(f'delete dir cmd: {cmd}')
+    ssh = pexpect.spawn(cmd)
+    try:
+        i = ssh.expect([is_input_yes, password_key, pexpect.EOF, pexpect.TIMEOUT], timeout=60)
+        if i == 0:
+            ssh.sendline('yes')
+            ssh.expect(password_key)
+            ssh.sendline(password)
+        elif i == 1:
+            ssh.sendline(password)
+        ssh.expect(pexpect.EOF)
         return True
     except pexpect.EOF:
         print('EOF')
@@ -394,10 +433,9 @@ def ssh_create_file(path, ip, user_name, password, port=22):
             ssh.sendline('yes')
             ssh.expect(password_key)
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
         elif i == 1:
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
+        ssh.expect(pexpect.EOF)
         return True
     except pexpect.EOF:
         print('EOF')
@@ -415,6 +453,7 @@ def ssh_create_dir(path, ip, user_name, password, port=22):
         return False
     # cmd = 'ssh %s@%s mkdir %s' % (user_name, ip, path)
     cmd = 'ssh -p %s %s@%s mkdir %s' % (port, user_name, ip, path)
+    print(f'create dir cmd: {cmd}')
     ssh = pexpect.spawn(cmd)
     try:
         i = ssh.expect([is_input_yes, password_key, pexpect.EOF, pexpect.TIMEOUT], timeout=60)
@@ -422,10 +461,12 @@ def ssh_create_dir(path, ip, user_name, password, port=22):
             ssh.sendline('yes')
             ssh.expect(password_key)
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
         elif i == 1:
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
+        # 执行完命令后，会有一个EOF，需要expect一下，并打印出来
+        ssh_before = ssh.expect(pexpect.EOF)
+        print(f'ssh before: {ssh_before}')
+        ssh.close()
         return True
     except pexpect.EOF:
         print('EOF')
@@ -440,31 +481,24 @@ def ssh_create_dir(path, ip, user_name, password, port=22):
 def ssh_get_file_size(path, ip, user_name, password, port=22):
     # cmd = 'ssh %s@%s du -sh %s' % (user_name, ip, path)
     cmd = 'ssh -p %s %s@%s du -sh %s' % (port, user_name, ip, path)
+    print(f'get file size cmd: {cmd}')
     ssh = pexpect.spawn(cmd)
     try:
         i = ssh.expect([is_input_yes, password_key, pexpect.EOF, pexpect.TIMEOUT], timeout=60)
+        print(f'get file size i: {i}')
         if i == 0:
             ssh.sendline('yes')
             ssh.expect(password_key)
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
-            before_str = ssh.before
-            # 判断before_str是为bytes类型还是str类型
-            if isinstance(before_str, bytes):
-                before_str = before_str.decode('utf-8')
-            file_size = before_str.split('\r\n')[1].split()[0]
-            return file_size
         elif i == 1:
             ssh.sendline(password)
-            ssh.expect(pexpect.EOF)
-            before_str = ssh.before
-            # 判断before_str是为bytes类型还是str类型
-            if isinstance(before_str, bytes):
-                before_str = before_str.decode('utf-8')
-            file_size = before_str.split('\r\n')[1].split()[0]
-            return file_size
-        else:
-            return None
+        ssh.expect(pexpect.EOF)
+        before_str = ssh.before
+        # 判断before_str是为bytes类型还是str类型
+        if isinstance(before_str, bytes):
+            before_str = before_str.decode('utf-8')
+        file_size = before_str.split('\r\n')[1].split()[0]
+        return file_size
     except pexpect.EOF:
         print('EOF')
         ssh.close()
@@ -473,6 +507,36 @@ def ssh_get_file_size(path, ip, user_name, password, port=22):
         print('TIMEOUT')
         ssh.close()
         return None
+    
+# 写一个异步下载文件的方法，使用回调函数能够实时获取下载进度以及下载速度
+async def ssh_download_file_async(path, local_path, ip, user_name, password, port=22, callback=None):
+    # 先判断path是否存在
+    if not ssh_get_file_list(path, ip, user_name, password, port):
+        return False
+    # cmd = 'scp %s@%s:%s %s' % (user_name, ip, path, local_path)
+    cmd = 'scp -P %s %s@%s:%s %s' % (port, user_name, ip, path, local_path)
+    print(f'download file cmd: {cmd}')
+    ssh = pexpect.spawn(cmd)
+    try:
+        i = ssh.expect([is_input_yes, password_key, pexpect.EOF, pexpect.TIMEOUT], timeout=60)
+        print(f'download file i: {i}')
+        if i == 0:
+            ssh.sendline('yes')
+            ssh.expect(password_key)
+            ssh.sendline(password)
+        elif i == 1:
+            ssh.sendline(password)
+        ssh.expect(pexpect.EOF)
+        return True
+    except pexpect.EOF:
+        print('EOF')
+        ssh.close()
+        return False
+    except pexpect.TIMEOUT:
+        print('TIMEOUT')
+        ssh.close()
+        return False
+        
 
 
 def process_callback(p, f):
@@ -483,9 +547,11 @@ if __name__ == '__main__':
     ip = '39.101.69.111'
     user_name = 'root'
     password = 'Dxr85578595'
-    res = ssh_download_file('/root/test.zip', './', ip, user_name, password, callback=process_callback)
-    print(res)
-
-
-    
-    
\ No newline at end of file
+    # res = ssh_download_file('/root/test.zip', './', ip, user_name, password, callback=process_callback)
+    # print(ssh_is_file_exist('/root/test1.zip', ip, user_name, password))
+    # print(ssh_get_file_list('/root1', ip, user_name, password))
+    # print(ssh_upload_file('./error.log', '/root', ip, user_name, password))
+    # print(ssh_rename_file('/root/error1.log', '/root/error.log', ip, user_name, password))
+    # print(ssh_delete_file('/root/error.log', ip, user_name, password))
+    # print(ssh_create_dir('/root/test', ip, user_name, password))
+    print(ssh_delete_dir('/root/test', ip, user_name, password))
\ No newline at end of file
